==> showimg_0.7.orig.tar.gz: showimg-0.7.orig/showimg/ProgressDialog.cpp <==
/***************************************************************************
                          ProgressDialog.cpp  -  description
                             -------------------
    begin                : Die Mai 15 15:34:19 CEST 2001
    copyright            : (C) 2001 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "ProgressDialog.h"

#include <qapplication.h>

#include <klocale.h>

ProgressDialog::ProgressDialog( QWidget* parent, bool p,const char* name, bool modal, WFlags fl )
    : QProgressDialog( parent, name, modal, fl )
{
        setCaption(i18n("Rename Series..."));
}

ProgressDialog::~ProgressDialog()
{
}

void ProgressDialog::inc(  )
{
        done++;
        setProgress(done);
	qApp->processEvents();
}

void ProgressDialog::init( int numOfFiles )
{
        done=0;
	setTotalSteps(numOfFiles);
	reset();
}


void ProgressDialog::print(QString text )
{
    setLabelText(text);
    return;
}
void ProgressDialog::print(QString in, QString out )
{
    setLabelText(in+
    		"->\n"+
                out);
    return;
}

void ProgressDialog::quitAll()
{
    if(!preview)
        QApplication::exit(0);
    else
        delete this;
}

==> showimg_0.9.1.orig.tar.gz: showimg-0.9.1/showimg/ProgressDialog.cpp <==
/***************************************************************************
                          ProgressDialog.cpp  -  description
                             -------------------
    begin                : Die Mai 15 15:34:19 CEST 2001
    copyright            : (C) 2001 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "ProgressDialog.h"

#include <kapplication.h>
#include <klocale.h>

ProgressDialog::ProgressDialog( QWidget* parent, bool , const char* name, bool modal, WFlags fl )
    : QProgressDialog( parent, name, modal, fl )
{
        setCaption(i18n("Rename Series..."));
}

ProgressDialog::~ProgressDialog()
{
}

void ProgressDialog::inc(  )
{
        done++;
        setProgress(done);
	kapp->processEvents();
}

void ProgressDialog::init( int numOfFiles )
{
        done=0;
	setTotalSteps(numOfFiles);
	reset();
}

void ProgressDialog::print(QString in, QString out)
{
    setLabelText(in+(out==""?(QString)"->\n"+out:(QString)""));
    return;
}

void ProgressDialog::quitAll()
{
    if(!preview)
        KApplication::exit(0);
    else
        delete this;
}

#include "ProgressDialog.moc"
